==> qwerkisync_0.0.1.tar.gz: qwerkisync-0.0.1/EventParsers/VMGEntities/VCalendar.h <==
/*
 * Copyright (C) 2011, Jamie Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef EVENTPARSERS_VMGEntities_VCALENDAR_H
#define EVENTPARSERS_VMGEntities_VCALENDAR_H

#include "SMSEntity.h"
#include "iReader.h"
#include "iWriter.h"

class QString;

namespace EventTypes { class SMS; }

namespace EventParsers
{
	namespace VMGEntities
	{
		class VCalendar : public SMSEntity, public iWriter, public iReader
		{
		public:
			VCalendar (const SMSEntity *parent);
			//VCalendar (QTextStream& stream);
			VCalendar (const SMSEntity *parent, float version);
			~VCalendar ();

			virtual bool Read(const QString &initialLine, QTextStream &stream, EventTypes::SMS &event);
			virtual void Write(QTextStream &stream, const EventTypes::SMS &event);

		protected:
			virtual const char *getTagName() const { return "VCALENDAR"; }

		private:
			float m_Version;
		};
	}
}

#endif // EVENTPARSERS_VMGEntities_VCALENDAR_H

==> qwerkisync_0.0.2.tar.gz: qwerkisync-0.0.2/EventParsers/VMGEntities/VCalendar.h <==
/*
 * Copyright (C) 2011, Jamie Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef EVENTPARSERS_VMGEntities_VCALENDAR_H
#define EVENTPARSERS_VMGEntities_VCALENDAR_H

#include "SMSEntity.h"
#include "iReader.h"
#include "iWriter.h"

class QString;

namespace EventTypes { class SMS; }

namespace EventParsers
{
	namespace VMGEntities
	{
		class VCalendar : public SMSEntity, public iWriter, public iReader
		{
		public:
			VCalendar (const Settings &settings, const SMSEntity *parent);
			//VCalendar (QTextStream& stream);
			VCalendar (const Settings &settings, const SMSEntity *parent, float version);
			~VCalendar ();

			virtual bool Read(const QString &initialLine, QTextStream &stream, EventTypes::SMS &event);
			virtual void Write(QTextStream &stream, const EventTypes::SMS &event, const NumberToNameLookup &numberToNameLookup);

		protected:
			virtual const char *getTagName() const { return "VCALENDAR"; }

		private:
			float m_Version;
		};
	}
}

#endif // EVENTPARSERS_VMGEntities_VCALENDAR_H
